@@ -31,7 +31,10 @@
 #include <KEMailSettings>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 #include <qt5keychain/keychain.h>
 using namespace QKeychain;
 #include <KWallet>
@@ -109,16 +112,17 @@ TransportManager::TransportManager()
     : QObject()
     , d(new TransportManagerPrivate(this))
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("transportmanager"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("mailtransports"));
     migrate.migrate();
-
+#endif
     qAddPostRoutine(destroyStaticTransportManager);
     d->config = new KConfig(QStringLiteral("mailtransports"));
 
     QDBusConnection::sessionBus().registerObject(DBUS_OBJECT_PATH, this, QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals);
 
-    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(DBUS_SERVICE_NAME, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration, this);
+    auto watcher = new QDBusServiceWatcher(DBUS_SERVICE_NAME, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration, this);
     connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() {
         d->dbusServiceUnregistered();
     });
@@ -147,7 +151,7 @@ TransportManager *TransportManager::self()
 
 Transport *TransportManager::transportById(int id, bool def) const
 {
-    for (Transport *t : qAsConst(d->transports)) {
+    for (Transport *t : std::as_const(d->transports)) {
         if (t->id() == id) {
             return t;
         }
@@ -161,7 +165,7 @@ Transport *TransportManager::transportById(int id, bool def) const
 
 Transport *TransportManager::transportByName(const QString &name, bool def) const
 {
-    for (Transport *t : qAsConst(d->transports)) {
+    for (Transport *t : std::as_const(d->transports)) {
         if (t->name() == name) {
             return t;
         }
@@ -185,7 +189,7 @@ TransportType::List TransportManager::types() const
 Transport *TransportManager::createTransport() const
 {
     int id = d->createId();
-    Transport *t = new Transport(QString::number(id));
+    auto t = new Transport(QString::number(id));
     t->setId(id);
     return t;
 }
@@ -320,7 +324,7 @@ QVector<int> TransportManager::transportIds() const
 {
     QVector<int> rv;
     rv.reserve(d->transports.count());
-    for (Transport *t : qAsConst(d->transports)) {
+    for (Transport *t : std::as_const(d->transports)) {
         rv << t->id();
     }
     return rv;
@@ -330,7 +334,7 @@ QStringList TransportManager::transportNames() const
 {
     QStringList rv;
     rv.reserve(d->transports.count());
-    for (Transport *t : qAsConst(d->transports)) {
+    for (Transport *t : std::as_const(d->transports)) {
         rv << t->name();
     }
     return rv;
@@ -517,7 +521,7 @@ int TransportManagerPrivate::createId() const
 {
     QVector<int> usedIds;
     usedIds.reserve(1 + transports.count());
-    for (Transport *t : qAsConst(transports)) {
+    for (Transport *t : std::as_const(transports)) {
         usedIds << t->id();
     }
     usedIds << 0; // 0 is default for unknown
@@ -570,7 +574,7 @@ void TransportManagerPrivate::prepareWallet()
 
 void TransportManager::loadPasswords()
 {
-    for (Transport *t : qAsConst(d->transports)) {
+    for (Transport *t : std::as_const(d->transports)) {
         t->readPassword();
     }
 
@@ -590,7 +594,7 @@ void TransportManager::loadPasswordsAsync()
 
     // check if there is anything to do at all
     bool found = false;
-    for (Transport *t : qAsConst(d->transports)) {
+    for (Transport *t : std::as_const(d->transports)) {
         if (!t->isComplete()) {
             found = true;
             break;
@@ -669,7 +673,7 @@ void TransportManagerPrivate::migrateToWallet()
 
     // check if migration is needed
     QStringList names;
-    for (Transport *t : qAsConst(transports)) {
+    for (Transport *t : std::as_const(transports)) {
         if (t->needsWalletMigration()) {
             names << t->name();
         }
@@ -696,7 +700,7 @@ void TransportManagerPrivate::migrateToWallet()
     }
 
     // perform migration
-    for (Transport *t : qAsConst(transports)) {
+    for (Transport *t : std::as_const(transports)) {
         if (t->needsWalletMigration()) {
             t->migrateToWallet();
         }
