@@ -46,7 +46,7 @@ void FilterActionJob::Private::fetchResult(KJob *job)
         return;
     }
 
-    auto *fjob = dynamic_cast<ItemFetchJob *>(job);
+    auto fjob = dynamic_cast<ItemFetchJob *>(job);
     Q_ASSERT(fjob);
     Q_ASSERT(items.isEmpty());
     items = fjob->items();
@@ -57,7 +57,7 @@ void FilterActionJob::Private::traverseItems()
 {
     Q_ASSERT(functor);
     qCDebug(MAILTRANSPORTAKONADI_LOG) << "Traversing" << items.count() << "items.";
-    for (const Item &item : qAsConst(items)) {
+    for (const Item &item : std::as_const(items)) {
         if (functor->itemAccepted(item)) {
             functor->itemAction(item, q);
             qCDebug(MAILTRANSPORTAKONADI_LOG) << "Added subjob for item" << item.id();
